@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2012-2014 The python-semanticversion project
+# Copyright (c) The python-semanticversion project
 # This code is distributed under the two-clause BSD License.
 
 try:  # pragma: no cover
+    import django
     from django.conf import settings
     django_loaded = True
 except ImportError:  # pragma: no cover
@@ -20,5 +21,10 @@ if django_loaded:  # pragma: no cover
             },
             INSTALLED_APPS=[
                 'tests.django_test_app',
-            ]
+            ],
+            MIDDLEWARE_CLASSES=[],
         )
+    # https://docs.djangoproject.com/en/dev/releases/1.7/#app-loading-changes
+    if django.VERSION >= (1, 7):
+        from django.apps import apps
+        apps.populate(settings.INSTALLED_APPS)
